TransferFunctions
=================

.. toctree::
   :maxdepth: 3

.. automodule:: psyneulink.core.components.functions.transferfunctions
   :members: Identity, Linear, Exponential, Logistic, Tanh, ReLU, Gaussian, Normal, SoftMax, LinearMatrix
   :exclude-members: Parameters
